==> scalarx_2.10-0.2.3-JS.jar: rx/core/Rx$.js <==
/** @constructor */
ScalaJS.c.rx_core_Rx$ = (function() {
  ScalaJS.c.java_lang_Object.call(this)
});
ScalaJS.c.rx_core_Rx$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_core_Rx$.prototype.constructor = ScalaJS.c.rx_core_Rx$;
ScalaJS.c.rx_core_Rx$.prototype.apply__Lscala_Function0__Lrx_core_Rx = (function(calc) {
  return new ScalaJS.c.rx_core_Dynamic().init___Lscala_Function0__T(calc, ScalaJS.modules.rx_core_Dynamic().$$lessinit$greater$default$2__T())
});
ScalaJS.c.rx_core_Rx$.prototype.apply__Lrx_core_Rx$Cookie$__T__Lscala_Function0__Lrx_core_Rx = (function(c, name, calc) {
  return new ScalaJS.c.rx_core_Dynamic().init___Lscala_Function0__T(calc, name)
});
ScalaJS.c.rx_core_Rx$.prototype.apply$default$1__Lrx_core_Rx$Cookie$ = (function() {
  return ScalaJS.modules.rx_core_Rx$Cookie()
});
ScalaJS.c.rx_core_Rx$.prototype.apply$default$2__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Rx$.prototype.apply__Lrx_core_Rx$Cookie$__T__Lscala_Function0__ = (function(c, name, calc) {
  return this.apply__Lrx_core_Rx$Cookie$__T__Lscala_Function0__Lrx_core_Rx(c, name, calc)
});
ScalaJS.c.rx_core_Rx$.prototype.apply__Lscala_Function0__ = (function(calc$2) {
  return this.apply__Lscala_Function0__Lrx_core_Rx(calc$2)
});
/** @constructor */
ScalaJS.inheritable.rx_core_Rx$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_core_Rx$.prototype = ScalaJS.c.rx_core_Rx$.prototype;
ScalaJS.is.rx_core_Rx$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_core_Rx$)))
});
ScalaJS.as.rx_core_Rx$ = (function(obj) {
  if ((ScalaJS.is.rx_core_Rx$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.core.Rx")
  }
});
ScalaJS.isArrayOf.rx_core_Rx$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_core_Rx$)))
});
ScalaJS.asArrayOf.rx_core_Rx$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_core_Rx$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.core.Rx;", depth)
  }
});
ScalaJS.data.rx_core_Rx$ = new ScalaJS.ClassTypeData({
  rx_core_Rx$: 0
}, false, "rx.core.Rx$", ScalaJS.data.java_lang_Object, {
  rx_core_Rx$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_core_Rx$.prototype.$classData = ScalaJS.data.rx_core_Rx$;
ScalaJS.moduleInstances.rx_core_Rx = undefined;
ScalaJS.modules.rx_core_Rx = (function() {
  if ((!ScalaJS.moduleInstances.rx_core_Rx)) {
    ScalaJS.moduleInstances.rx_core_Rx = new ScalaJS.c.rx_core_Rx$().init___()
  };
  return ScalaJS.moduleInstances.rx_core_Rx
});
//@ sourceMappingURL=Rx$.js.map

==> scalarx_2.10-0.2.4-JS.jar: rx/core/Rx$.js <==
/** @constructor */
ScalaJS.c.rx_core_Rx$ = (function() {
  ScalaJS.c.java_lang_Object.call(this)
});
ScalaJS.c.rx_core_Rx$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_core_Rx$.prototype.constructor = ScalaJS.c.rx_core_Rx$;
ScalaJS.c.rx_core_Rx$.prototype.apply__Lscala_Function0__Lrx_core_Rx = (function(calc) {
  return new ScalaJS.c.rx_core_Dynamic().init___Lscala_Function0__T(calc, ScalaJS.modules.rx_core_Dynamic().$$lessinit$greater$default$2__T())
});
ScalaJS.c.rx_core_Rx$.prototype.apply__Lrx_core_Rx$Cookie$__T__Lscala_Function0__Lrx_core_Rx = (function(c, name, calc) {
  return new ScalaJS.c.rx_core_Dynamic().init___Lscala_Function0__T(calc, name)
});
ScalaJS.c.rx_core_Rx$.prototype.apply$default$1__Lrx_core_Rx$Cookie$ = (function() {
  return ScalaJS.modules.rx_core_Rx$Cookie()
});
ScalaJS.c.rx_core_Rx$.prototype.apply$default$2__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Rx$.prototype.apply$default$2__ = (function() {
  return this.apply$default$2__T()
});
ScalaJS.c.rx_core_Rx$.prototype.apply$default$1__ = (function() {
  return this.apply$default$1__Lrx_core_Rx$Cookie$()
});
ScalaJS.c.rx_core_Rx$.prototype.apply__Lrx_core_Rx$Cookie$__T__Lscala_Function0__ = (function(c, name, calc) {
  return this.apply__Lrx_core_Rx$Cookie$__T__Lscala_Function0__Lrx_core_Rx(c, name, calc)
});
ScalaJS.c.rx_core_Rx$.prototype.apply__Lscala_Function0__ = (function(calc$2) {
  return this.apply__Lscala_Function0__Lrx_core_Rx(calc$2)
});
/** @constructor */
ScalaJS.inheritable.rx_core_Rx$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_core_Rx$.prototype = ScalaJS.c.rx_core_Rx$.prototype;
ScalaJS.is.rx_core_Rx$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_core_Rx$)))
});
ScalaJS.as.rx_core_Rx$ = (function(obj) {
  if ((ScalaJS.is.rx_core_Rx$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.core.Rx")
  }
});
ScalaJS.isArrayOf.rx_core_Rx$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_core_Rx$)))
});
ScalaJS.asArrayOf.rx_core_Rx$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_core_Rx$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.core.Rx;", depth)
  }
});
ScalaJS.data.rx_core_Rx$ = new ScalaJS.ClassTypeData({
  rx_core_Rx$: 0
}, false, "rx.core.Rx$", ScalaJS.data.java_lang_Object, {
  rx_core_Rx$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_core_Rx$.prototype.$classData = ScalaJS.data.rx_core_Rx$;
ScalaJS.moduleInstances.rx_core_Rx = undefined;
ScalaJS.modules.rx_core_Rx = (function() {
  if ((!ScalaJS.moduleInstances.rx_core_Rx)) {
    ScalaJS.moduleInstances.rx_core_Rx = new ScalaJS.c.rx_core_Rx$().init___()
  };
  return ScalaJS.moduleInstances.rx_core_Rx
});
//@ sourceMappingURL=Rx$.js.map
